ErrorInfoReader class
Reads error information from a given error string.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cleanupTestErrors(
List< String> lines) → List<String> - Removes unneccesary information from test output
-
extractErrorLines(
String message) → List< String> - Returns the error lines from a given message.
-
filePathes(
String? error) → List< String> - Returns all Vscode formatted error lines from the given error string.
-
makeVscodeCompatible(
String message) → String - Replaces error lines in the given message with vscode compatible ones.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited